import React from 'react'
import { Container, Grid, Icon } from 'semantic-ui-react'
import { Link } from 'react-router'
import styled from 'styled-components'
import utils from '../../utils/utils.js'
import logo from '../../images/logo/main.png'

const StyledFooter = styled.div`
  background: rgba(0,0,0,0.02);
  padding: 10px;
`

export default function Footer () {
  return (
    <StyledFooter>
      <Container>
        <Grid verticalAlign='middle' stackable columns={2}>
          <Grid.Column>
            <Link to='/'><img alt={`${utils.appName()} logo`} src={logo} style={{ width: '100px', opacity: 0.5 }} /></Link>
            {import.meta.env.VITE_SOURCE_REPO_URL &&
              <p style={{ marginTop: 5 }}>
                <small>{utils.appName()} software is free and open-source.
                  <br />
                  <Icon name='code' /> <a href={import.meta.env.VITE_SOURCE_REPO_URL} target='_blank' rel='noopener noreferrer' className='umami--click--source-footer'>Project source homepage</a>
                </small>
              </p>}
          </Grid.Column>
          <Grid.Column textAlign='right' style={{ fontSize: 13 }}>
            {import.meta.env.VITE_PATREON_URL &&
              <p>
                <Icon name='trophy' />
                <a href={import.meta.env.VITE_PATREON_URL} target='_blank' rel='noopener noreferrer' className='umami--click--patreon-footer'>Become a patron</a>
              </p>}
            <p>
              <Icon name='book' />
              <a href='/docs' target='_blank' rel='noopener noreferrer'>Documentation</a>
            </p>
            {import.meta.env.VITE_PRIVACY_POLICY_URL &&
              <p>
                <Icon name='file alternate outline' />
                <a target='_blank' href={import.meta.env.VITE_PRIVACY_POLICY_URL} rel='noreferrer'>Privacy Policy</a>
              </p>}
            {import.meta.env.VITE_TERMS_OF_USE_URL &&
              <p>
                <Icon name='file alternate outline' />
                <a target='_blank' href={import.meta.env.VITE_TERMS_OF_USE_URL} rel='noreferrer'>Terms of Use</a>
              </p>}
            {import.meta.env.VITE_ONLINE_SAFETY_URL &&
              <p>
                <Icon name='file alternate outline' />
                <a href={import.meta.env.VITE_ONLINE_SAFETY_URL} target='_blank' rel='noopener noreferrer'>Online Safety</a>
              </p>}
            {import.meta.env.VITE_STATUS_URL &&
              <p>
                <a target='_blank' rel='noopener noreferrer' href={import.meta.env.VITE_STATUS_URL}>
                  <img src={import.meta.env.VITE_STATUS_BADGE_URL} />
                </a>
              </p>}
          </Grid.Column>
        </Grid>
      </Container>
    </StyledFooter>
  )
}
